// openhomm - open source clone of Heroes of Might and Magic III
// Copyright (C) 2009-2010 openhomm developers team (see AUTHORS)
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
#include "precompiled.hpp"
#include "hrBorder.hpp"
#include "hrCache.hpp"

int hrBorder::getWidth() const
{
    return rect.width();
}

void hrBorder::setWidth(int w)
{
    rect.setWidth(w);
    resizeBorder(rect.width(), rect.height());
}

int hrBorder::getHeight() const
{
    return rect.height();
}

void hrBorder::setHeight(int h)
{
    rect.setHeight(h);
    resizeBorder(rect.width(), rect.height());
}

QString hrBorder::getName() const
{
    return name;
}

void hrBorder::setCoords(QList<int> array)
{
    if (array.isEmpty() || array.size() < 32)
    {
        qWarning("hrBorder: wrong coords");
        return;
    }

    hrCache &cache = hrCache::Get();
    QImage im("vfs:/" + name);

    v.clear();
    for (int i = 0; i < 32; i += 4)
    {
        v.append(cache.loadItem(im.copy( array.at(i)
                                       , array.at(i + 1)
                                       , array.at(i + 2)
                                       , array.at(i + 3)
                                       )
                                )
                 );
    }
}

void hrBorder::setName(QString name)
{
    this->name = name;
}

void hrBorder::resizeBorder(int w, int h)
{
    items.clear();

    addItem(v.at(topLeft), 0, 0);

    for (int y = v.at(topLeft).height(); y < h; y += v.at(left).height())
        addItem(v.at(left), 0, y);

    for (int x = v.at(topLeft).width(); x < w; x += v.at(top).width())
        addItem(v.at(top), x, 0);

    addItem(v.at(bottomLeft), 0, h - v.at(bottomLeft).height());

    for (int x = v.at(bottomLeft).width(); x < w; x += v.at(bottom).width())
        addItem(v.at(bottom), x, h - v.at(bottom).height());

    addItem(v.at(topRight), w - v.at(topRight).width(), 0);

    for (int y = v.at(topRight).height(); y < h; y += v.at(right).height())
        addItem(v.at(right), w - v.at(right).width(), y);

    addItem(v.at(bottomRight)
            , w - v.at(bottomRight).width()
            , h - v.at(bottomRight).height());
}

void hrBorder::addItem(hrGraphicsItem item, int x, int y)
{
    item.setPoint(QPoint(x, y));
    items.append(item);
}
